**EN 1993-1-1 - May 2005
Eurocode 3: Design of steel structures
Part 1-1: General rules and rules for buildings**

The table presents a list of tables from the Eurocode 3 standards for steel structures, tracking their implementation
status (:x: or :heavy_check_mark:)
and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

The column with header 'NL' for example indicates whether a country specific implementation of the table is 
implemented. Naming convention for country specific table is 'Table{table_number}{CountryCode}'. E.g. for 
`Table3Dot1NominalValuesHotRolledStructuralSteel` the version specific to the Netherlands would be named
`Table3Dot1NLNominalValuesHotRolledStructuralSteel`.

Total of 20 tables present.

| Table number |        Done        | Remarks | Object name                                     | NL  |
|:-------------|:------------------:|:--------|:------------------------------------------------|:---:|
| 3.1          | :heavy_check_mark: |         | Table3Dot1NominalValuesHotRolledStructuralSteel | :x: |
| 3.2          |        :x:         |         |                                                 | :x: |
| 5.1          |        :x:         |         |                                                 | :x: |
| 5.2          |        :x:         |         |                                                 | :x: |
| 6.1          |        :x:         |         |                                                 | :x: |
| 6.2          |        :x:         |         |                                                 | :x: |
| 6.3          |        :x:         |         |                                                 | :x: |
| 6.4          |        :x:         |         |                                                 | :x: |
| 6.5          |        :x:         |         |                                                 | :x: |
| 6.6          |        :x:         |         |                                                 | :x: |
| 6.7          |        :x:         |         |                                                 | :x: |
| 6.8          |        :x:         |         |                                                 | :x: |
| 6.9          |        :x:         |         |                                                 | :x: |
| A.1          |        :x:         |         |                                                 | :x: |
| A.2          |        :x:         |         |                                                 | :x: |
| B.1          |        :x:         |         |                                                 | :x: |
| B.2          |        :x:         |         |                                                 | :x: |
| B.3          |        :x:         |         |                                                 | :x: |
| BB.1         |        :x:         |         |                                                 | :x: |
| C.1          |        :x:         |         |                                                 | :x: |

The table below presents a list of tables from the Eurocode 3 standards for steel structures, specific to the 
National Annex of the Netherlands.

| Table number | Done | Remarks | Object name |
|:-------------|:----:|:--------|:------------|
| NB.C.1       | :x:  |         |             |
| NB.NA.1      | :x:  |         |             |
| NB.NA.2      | :x:  |         |             |
| NB.NA.3      | :x:  |         |             |
| NB.NA.4      | :x:  |         |             |
| NB.NA.5      | :x:  |         |             |
| NB.NB.1      | :x:  |         |             |
| NB.NB.2      | :x:  |         |             |
| NB.NB.3      | :x:  |         |             |
